Library for interfacing with Nikon DSLR through IR LED

Dependencies:   mbed

Revision:
1:bdc12143ced7
Parent:
0:e977f7ad0d48
--- a/main.cpp	Fri Apr 26 00:18:24 2019 +0000
+++ b/main.cpp	Fri Apr 26 00:25:02 2019 +0000
@@ -1,25 +1,19 @@
 /**
-* MBED code functionality, including idea of modulating PWM signal, taken from
-* https://os.mbed.com/users/viswesr/code/DSLR_Camera_IR_Remote/
-* As the given values did not work on the Nikon D3300, they were modified,
-* parameterized, and put into library form.
-* 
-* Inspiration, default values, and an Arduino validation signal were taken from
-* https://bayesianadventures.wordpress.com/2013/08/09/nikon-ml-l3-ir-remote-hack/
-*
-* Library instructions were taken from https://os.mbed.com/cookbook/Writing-a-Library
+* This program will transmit a modulated infrared signal to a Nikon DSLR using
+* a QED-123 IR LED
 */
+
 #include "mbed.h"
 #include "DslrIr.h"
 
-DigitalIn button(p20);  /* Push button to enable shutter release */
+DigitalIn trigger(p20);  /* Pull down trigger to enable shutter release */
 DslrIr dslr(p21);
 
 int main()
 {
-//    button.mode(PullUp);
+//    trigger.mode(PullUp);
     while(1) {
-        if(!button) {
+        if(!trigger) {
             dslr.trigger();
             wait(1);
         }